@@ -41,3 +41,5 @@ from holmes.models.keys import Key  # NOQA
 from holmes.models.settings import Settings  # NOQA
 from holmes.models.keys_category import KeysCategory  # NOQA
 from holmes.models.request import Request  # NOQA
+from holmes.models.user import User  # NOQA
+from holmes.models.limiter import Limiter # NOQA
